==> adyen-java-api-library-2.7.0-sources.jar: com/adyen/model/marketpay/notification/AccountHolderUpdatedNotification.java <==
/*
 *                       ######
 *                       ######
 * ############    ####( ######  #####. ######  ############   ############
 * #############  #####( ######  #####. ######  #############  #############
 *        ######  #####( ######  #####. ######  #####  ######  #####  ######
 * ###### ######  #####( ######  #####. ######  #####  #####   #####  ######
 * ###### ######  #####( ######  #####. ######  #####          #####  ######
 * #############  #############  #############  #############  #####  ######
 *  ############   ############  #############   ############  #####  ######
 *                                      ######
 *                               #############
 *                               ############
 *
 * Adyen Java API Library
 *
 * Copyright (c) 2017 Adyen B.V.
 * This file is open source and available under the MIT license.
 * See the LICENSE file for more info.
 */

package com.adyen.model.marketpay.notification;

import com.adyen.model.marketpay.UpdateAccountHolderResponse;
import com.google.gson.annotations.SerializedName;

public class AccountHolderUpdatedNotification extends GenericNotification {
    @SerializedName("content")
    private UpdateAccountHolderResponse content;

    public UpdateAccountHolderResponse getContent() {
        return content;
    }

    public void setContent(UpdateAccountHolderResponse content) {
        this.content = content;
    }

    @Override
    public String toString() {
        return "AccountHolderUpdatedNotification{" + "content=" + content + '}';
    }
}

==> adyen-java-api-library-12.0.1-sources.jar: com/adyen/model/marketpay/notification/AccountHolderUpdatedNotification.java <==
/*
 *                       ######
 *                       ######
 * ############    ####( ######  #####. ######  ############   ############
 * #############  #####( ######  #####. ######  #############  #############
 *        ######  #####( ######  #####. ######  #####  ######  #####  ######
 * ###### ######  #####( ######  #####. ######  #####  #####   #####  ######
 * ###### ######  #####( ######  #####. ######  #####          #####  ######
 * #############  #############  #############  #############  #####  ######
 *  ############   ############  #############   ############  #####  ######
 *                                      ######
 *                               #############
 *                               ############
 *
 * Adyen Java API Library
 *
 * Copyright (c) 2017 Adyen B.V.
 * This file is open source and available under the MIT license.
 * See the LICENSE file for more info.
 */

package com.adyen.model.marketpay.notification;

import com.adyen.model.marketpay.UpdateAccountHolderResponse;
import com.google.gson.annotations.SerializedName;

public class AccountHolderUpdatedNotification extends GenericNotification {
    @SerializedName("content")
    private UpdateAccountHolderResponse content;

    public UpdateAccountHolderResponse getContent() {
        return content;
    }

    public void setContent(UpdateAccountHolderResponse content) {
        this.content = content;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("AccountHolderUpdatedNotification{");
        sb.append("content=").append(content);
        sb.append('}');
        return sb.toString();
    }
}
